# An entropy method for geodynamic modeling of phase transitions: Capturing sharp and broad transitions in a multi-phase assemblage: Data

This repository accompanies the paper
```
An entropy method for geodynamic modeling of phase transitions: Capturing sharp and broad transitions in a multi-phase assemblage
by Juliane Dannberg, Rene Gassmoeller, Ranpeng Li, Carolina Lithgow-Bertelloni, Lars Stixrude
```

This repository contains ASPECT code, data, and model setups. To run the models in this repo follow the steps:

- The global spherical convection models of the publication presented in Section 3.3 were run using the following dependencies:

```
-----------------------------------------------------------------------------
-- This is ASPECT, the Advanced Solver for Problems in Earth's ConvecTion.
--     . version 2.4.0-pre (main, 8dcb250)
--     . using deal.II 9.4.0-pre
--     .       with 64 bit indices and vectorization level 2 (256 bits)
--     . using Trilinos 12.18.1
--     . using p4est 2.3.2
-----------------------------------------------------------------------------

```
This configuration was also used to compute the `convection_box_opx.prm` model in the `compare_phase_function_and_table` folder (Table model in Section 3.2). 

- Running these models requires plugins that are located in the `aspect/benchmarks/entropy_adiabat/plugins/` folder and that need to be compiled. Navigate into this directory and follow the steps:
 
  1. `cmake -D Aspect_DIR=PATH_TO_ASPECT` (replace `PATH_TO_ASPECT` with the directory where you compiled ASPECT).
  2. `make`
  
- Now the models in this repository can be started. You can start them with the ASPECT executable in your build folder.

___

- The models that reproduce the setup of Christensen & Yuen (1985) presented in Section 3.1 require a certain ASPECT branch because the adiabatic profile is computed in a slightly different way in Christensen & Yuen (1985) compared to how ASPECT usually does it. The easiest way to get the correct branch is to follow these git commands in your main ASPECT directory:

  1. `git remote add gassmoeller https://github.com/gassmoeller/aspect.git`
     *(This is only necessary once and gives an error if the remote already exists, if so nothing happens)*
  2. `git remote update gassmoeller`
  3. `git checkout gassmoeller/solve_entropy_equation`
  4. Recompile ASPECT as usual, with `cmake .` and `make -jX` (replace X by number of cores)
  

- Now the models in the other directories can be started. You can start them with the executable in your build folder.

- They were run using the following dependencies:

```
-----------------------------------------------------------------------------
--     . using deal.II 9.2.0
--     .       with 32 bit indices and vectorization level 2 (256 bits)
--     . using Trilinos 12.18.1
--     . using p4est 2.2.0
-----------------------------------------------------------------------------
```
This configuration was also used to compute the `convection_box_phase_function.prm` model in the `compare_phase_function_and_table` folder (corresponding to the three phase function models in Section 3.2). 

___


The models correspond to the manuscript sections as follows:

- Section 3.1: The effect of phase transition thickness: `christensen_yuen_1985_Ra_width`
- Section 3.2: The effect of latent heat: `compare_phase_function_and_table`
- Section 3.3: Spherical convection models: `spherical_convection_models`

The directories contain parameter files that should run individually for one of the setups of the publication. Some also contain shell scripts that will start all models of a model series. Some also contain python scripts to generate the figures.

___


The models presented in Appendix A are part of ASPECT's main repository and are located in the folder 
`aspect/benchmarks/entropy_adiabat/`. 

- `entropy_adiabat.prm` corresponds to A1 Advection along an adiabat
- `entropy_half_space.prm` corresponds to A2 Conductive cooling of a half-space
- `entropy_conduction.prm` corresponds to A3 Conductive cooling of an adiabat

